

library(easyNCDF)
source("../data-analysis/R_Reorder.R")
library(s2dverification)
library(CSTools)
library(RColorBrewer) library(multiApply)

plot_corr <- function(file.name, var, sdate, outdir, type, s2s,project=NULL){

  var <- "WSDI"
  filename <- paste0("/esarchive/oper/MEDGOLD-data/monthly_statistics/",
                     var,"/",var,"-corr_month03.nc")
  outfile <- paste0("/esarchive/scratch/lpalma/",
                    var,"-corr_month03.png")

  corr <- NcToArray(filename, vars_to_read='corr')
  lon <- NcToArray(filename, vars_to_read='longitude')
  lat <- NcToArray(filename, vars_to_read='latitude')
  time <- NcToArray(filename, vars_to_read='time')

  corr <- Reorder(corr, c("var","time","longitude","latitude"))


  col2 <- c("#0C046E", "#1914BE", "#2341F7", "#2F55FB", "#3E64FF", "#528CFF", "#64AAFF", 
	    "#82C8FF", "#A0DCFF", "#B4F0FF", "#FFFBAF", "#FFDD9A", "#FFBF87", "#FFA173", 
	    "#FF7055", "#FE6346", "#F7403B", "#E92D36", "#C80F1E", "#A50519")

  brks <- seq(-1,1,by=0.1)
  color <- colorRampPalette(col2)(length(brks)-1)
  options(bitmapType="cairo")

  PlotLayout(PlotEquiMap, c('longitude','latitude'),
             corr, lon, lat, filled.continents=F, 
             brks=brks,
             #rxow_titles=row_titles, 
             cols=col2, 
             fileout=outfile , bar_label_digits=1)

}

plot_skill <- function(file.name, var, sdate, outdir, type, s2s,project=NULL){

  var <- "WSDI"
  filename <- paste0("/esarchive/oper/MEDGOLD-data/monthly_statistics/",
                     var,"/",var,"-skill_month02.nc")
  outfile <- paste0("/esarchive/scratch/lpalma/",
                    var,"-skill_month02.png")

  corr <- NcToArray(filename, vars_to_read='corr')
  lon <- NcToArray(filename, vars_to_read='longitude')
  lat <- NcToArray(filename, vars_to_read='latitude')
  time <- NcToArray(filename, vars_to_read='time')

  corr <- Reorder(corr, c("var","time","longitude","latitude"))


  col2 <- c("#0C046E", "#1914BE", "#2341F7", "#2F55FB", "#3E64FF", "#528CFF", "#64AAFF", 
	    "#82C8FF", "#A0DCFF", "#B4F0FF", "#FFFBAF", "#FFDD9A", "#FFBF87", "#FFA173", 
	    "#FF7055", "#FE6346", "#F7403B", "#E92D36", "#C80F1E", "#A50519")

  brks <- seq(-100,100,by=10)
  color <- colorRampPalette(col2)(length(brks)-1)
  options(bitmapType="cairo")

  PlotLayout(PlotEquiMap, c('longitude','latitude'),
             corr, lon, lat, filled.continents=F, 
             brks=brks,
             #rxow_titles=row_titles, 
             cols=col2, 
             fileout=outfile , bar_label_digits=1)

}
plot_ensemblemean <- function(files.path, var, date, outdir, type, s2s){

  
  dimnames <- c('var','time', 'longitude', 'latitude')
  var <- "WSDI"
  filename <- paste0("/esarchive/oper/MEDGOLD-data/monthly_statistics/",
                     var,"/",var,"_20210301_03.nc")
  outfile <- paste0("/esarchive/scratch/lpalma/",
                    var,"_20210301.png")

  data <- NcToArray(filename, vars_to_read=var)
  data <- Apply(data, 'ensemble', mean, na.rm=T)[[1]]
  #data <- aperm(data,c(1,4,2,3))
  data <- Reorder(data,dimnames)
  names(dim(data)) <- dimnames

  lon <- NcToArray(filename, vars_to_read='longitude')
  lat <- NcToArray(filename, vars_to_read='latitude')
  
  cols <- c("#FFFBAF", "#FFDD9A", "#FFBF87", "#FFA173", 
	        "#FF7055", "#FE6346", "#F7403B", "#E92D36", "#C80F1E", "#A50519")

  PlotLayout(PlotEquiMap, c('longitude','latitude'), data, lon, 
             lat, filled.continents=F, fileout=outfile, 
             bar_label_digits=2)


}


